@@ -8,8 +8,8 @@ use crate::value::Value;
 
 
 pub struct Requests<'a, T> {
-    text: String, // 保存响应的数据,
-    url: &'a str,
+    pub text: String, // 保存响应的数据,
+    pub url: &'a str,
     store: &'a T,
 }
 
