@@ -8,6 +8,8 @@ mod requests_and_parser;
 fn test_db_store() {
     // test this usage: cargo test --test tests -- test_db_store 
     db_store::run_write_csv();
+    db_store::run_test_postgres();
+    db_store::run_test_sqlite();
 }
 
 #[test]
